@@ -1,7 +1,7 @@
 name = "pycromanager"
 
-from pycromanager.acquisitions import Acquisition,MagellanAcquisition, XYTiledAcquisition
-# from pycromanager.core_util import
+from pycromanager.acquisitions import Acquisition, MagellanAcquisition, XYTiledAcquisition
+from pycromanager.core_util import CoreCallback
 from pycromanager.acq_util import start_headless, multi_d_acquisition_events
 from pycromanager.zmq import Bridge, JavaObjectShadow
 from pycromanager.data import Dataset
